import { __decorate } from 'tslib';
import * as i0 from '@angular/core';
import { EventEmitter, Component, ViewEncapsulation, HostBinding, ViewChild, Input, Output, Pipe, inject, Optional, NgModule } from '@angular/core';
import { isString } from '@tethys/cdk';
import Cropper from 'cropperjs';
import { InputNumber } from 'ngx-tethys/core';
import { NgIf, NgFor, NgStyle, CommonModule } from '@angular/common';
import * as i1 from 'ngx-tethys/loading';
import { ThyLoadingModule } from 'ngx-tethys/loading';
import * as i1$1 from 'ngx-tethys/dialog';
import { ThyDialogModule } from 'ngx-tethys/dialog';
import { ThyNotifyService, ThyNotifyModule } from 'ngx-tethys/notify';
import * as i2 from 'ngx-tethys/slider';
import { ThySliderModule } from 'ngx-tethys/slider';
import { finalize } from 'rxjs/operators';
import { isString as isString$1 } from '@tethys/cdk/is';
import { ThyIcon, ThyIconModule } from 'ngx-tethys/icon';
import * as i5 from 'ngx-tethys/upload';
import { ThyUploadModule } from 'ngx-tethys/upload';
import * as i4 from 'ngx-tethys/button';
import { ThyButtonModule } from 'ngx-tethys/button';
import * as i3 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { ThyTooltipModule } from 'ngx-tethys/tooltip';

class ThyImageCropperComponent {
    /**
     * 图片资源
     */
    set imageSource(value) {
        if (value) {
            if (!isString(value)) {
                this.imageFile = value;
                this.setImageSrc();
            }
            else {
                this.imageSrc = value;
            }
        }
        else {
            this.onError();
        }
    }
    /**
     * 设置放大缩小
     */
    set thyScale(value) {
        this.scale = value;
        this.cropper?.scale(value);
    }
    /**
     * 设置旋转角度
     */
    set thyRotate(value) {
        this.cropper?.rotateTo(value);
    }
    constructor() {
        this.cropperClass = true;
        /**
         * 图片加载的错误提示
         * @default 图片加载错误
         */
        this.thyImageErrorMessage = '图片加载错误';
        /**
         * 设置裁剪形状
         */
        this.thyShape = 'rect';
        /**
         * 图片裁剪的数据更改(blob)
         * @default EventEmitter<thyCropDataChangeEvent>
         */
        this.thyCropDataChanged = new EventEmitter();
        /**
         * 图片加载完毕事件
         * @default EventEmitter<boolean>
         */
        this.thyImageReady = new EventEmitter();
        this.loadingDone = false;
        this.loadError = false;
        this.defaultCropperOptions = {
            viewMode: 1,
            aspectRatio: 1,
            movable: false,
            scalable: true,
            dragMode: 'move',
            cropBoxResizable: false,
            zoomable: true,
            guides: false,
            autoCrop: false,
            zoomOnWheel: true,
            checkCrossOrigin: true,
            preview: '.preview-image-warp',
            ready: (event) => {
                this.loadingDone = true;
                this.cropper.crop();
                return;
            }
        };
        this.scale = 1;
        this.crop = () => {
            const cropper = this.cropper;
            const canvas = cropper.getCroppedCanvas();
            const promise = new Promise((resolve) => {
                canvas.toBlob((blob) => resolve({ blob }));
            });
            promise.then((res) => {
                return this.thyCropDataChanged.emit(res);
            });
        };
    }
    ngOnInit() { }
    onLoad(event) {
        this.loadError = false;
        const image = event.target;
        image.addEventListener('ready', () => {
            this.thyImageReady.emit(true);
        });
        const { viewMode, aspectRatio } = this.defaultCropperOptions;
        const customCropperOptions = {
            viewMode: this.thyViewMode || this.thyViewMode === 0 ? this.thyViewMode : viewMode,
            aspectRatio: this.thyAspectRatio ? this.thyAspectRatio : aspectRatio
        };
        this.cropperOptions = Object.assign({
            ...this.defaultCropperOptions,
            crop: (event) => {
                this.crop();
            }
        }, customCropperOptions);
        if (this.cropperOptions?.checkCrossOrigin) {
            image.crossOrigin = 'anonymous';
        }
        if (this.cropper) {
            this.cropper.destroy();
            this.cropper = undefined;
        }
        this.cropper = new Cropper(image, this.cropperOptions);
    }
    onError(event) {
        this.loadError = true;
        this.loadingDone = true;
    }
    setImageSrc() {
        this.loadingDone = false;
        const reader = new FileReader();
        reader.onloadend = () => {
            const cropperRef = this.cropper;
            if (cropperRef) {
                cropperRef.destroy();
                cropperRef.replace(reader.result.toString(), true);
                cropperRef.reset();
            }
            this.imageSrc = reader.result.toString();
        };
        if (this.imageFile) {
            reader.readAsDataURL(this.imageFile);
        }
        else {
            this.imageSrc = '';
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyImageCropperComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: ThyImageCropperComponent, isStandalone: true, selector: "thy-image-cropper", inputs: { imageSource: ["thyImage", "imageSource"], thyImageErrorMessage: "thyImageErrorMessage", thyViewMode: "thyViewMode", thyAspectRatio: "thyAspectRatio", thyShape: "thyShape", thyScale: "thyScale", thyRotate: "thyRotate" }, outputs: { thyCropDataChanged: "thyCropDataChanged", thyImageReady: "thyImageReady" }, host: { properties: { "class.thy-image-cropper-round": "thyShape === \"round\"", "class.thy-image-cropper": "this.cropperClass" } }, viewQueries: [{ propertyName: "image", first: true, predicate: ["image"], descendants: true, static: true }], ngImport: i0, template: "<thy-loading [thyDone]=\"loadingDone\"></thy-loading>\n\n<div class=\"alert alert-warning\" *ngIf=\"loadError\">{{ thyImageErrorMessage }}</div>\n\n<div class=\"cropper-content\" [class.image-ready]=\"loadingDone\">\n  <img #image alt=\"image\" *ngIf=\"imageSrc\" [src]=\"imageSrc\" (load)=\"onLoad($event)\" (error)=\"onError($event)\" />\n</div>\n", dependencies: [{ kind: "ngmodule", type: ThyLoadingModule }, { kind: "component", type: i1.ThyLoading, selector: "thy-loading", inputs: ["thyDone", "thyTip", "thyIsMask"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    InputNumber()
], ThyImageCropperComponent.prototype, "thyScale", null);
__decorate([
    InputNumber()
], ThyImageCropperComponent.prototype, "thyRotate", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyImageCropperComponent, decorators: [{
            type: Component,
            args: [{ selector: 'thy-image-cropper', encapsulation: ViewEncapsulation.None, host: {
                        '[class.thy-image-cropper-round]': 'thyShape === "round"'
                    }, standalone: true, imports: [ThyLoadingModule, NgIf], template: "<thy-loading [thyDone]=\"loadingDone\"></thy-loading>\n\n<div class=\"alert alert-warning\" *ngIf=\"loadError\">{{ thyImageErrorMessage }}</div>\n\n<div class=\"cropper-content\" [class.image-ready]=\"loadingDone\">\n  <img #image alt=\"image\" *ngIf=\"imageSrc\" [src]=\"imageSrc\" (load)=\"onLoad($event)\" (error)=\"onError($event)\" />\n</div>\n" }]
        }], ctorParameters: () => [], propDecorators: { cropperClass: [{
                type: HostBinding,
                args: ['class.thy-image-cropper']
            }], image: [{
                type: ViewChild,
                args: ['image', { static: true }]
            }], imageSource: [{
                type: Input,
                args: ['thyImage']
            }], thyImageErrorMessage: [{
                type: Input
            }], thyViewMode: [{
                type: Input
            }], thyAspectRatio: [{
                type: Input
            }], thyShape: [{
                type: Input
            }], thyScale: [{
                type: Input
            }], thyRotate: [{
                type: Input
            }], thyCropDataChanged: [{
                type: Output
            }], thyImageReady: [{
                type: Output
            }] } });

class ThyCropperSizeTextPipe {
    transform(size, previewSizes) {
        if (size || previewSizes) {
            const currentSize = previewSizes ? previewSizes[0] : size;
            const width = parseFloat(currentSize.width);
            const height = parseFloat(currentSize.height);
            return width + ' x ' + height;
        }
        else {
            return '';
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyCropperSizeTextPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.2.3", ngImport: i0, type: ThyCropperSizeTextPipe, isStandalone: true, name: "thyCropperSizeText" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyCropperSizeTextPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'thyCropperSizeText',
                    standalone: true
                }]
        }] });
class ThyCropperSizeStylePipe {
    transform(size) {
        if (size) {
            const { width, height } = size;
            if (width && height) {
                const stringWidth = isString$1(width) ? width : `${width}px`;
                const stringHeight = isString$1(height) ? height : `${height}px`;
                return { width: `${stringWidth}`, height: `${stringHeight}` };
            }
            else {
                return { width: '100%', height: '100%' };
            }
        }
        else {
            return { width: '100%', height: '100%' };
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyCropperSizeStylePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.2.3", ngImport: i0, type: ThyCropperSizeStylePipe, isStandalone: true, name: "thyCropperSizeStyle" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyCropperSizeStylePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'thyCropperSizeStyle',
                    standalone: true
                }]
        }] });

class ThyImageCropperDialogComponent {
    constructor(dialog, dialogContainer, ngZone) {
        this.dialog = dialog;
        this.dialogContainer = dialogContainer;
        this.ngZone = ngZone;
        /**
         * 标题
         * @default 图片
         */
        this.title = '图片';
        /**
         * 上传提示文案
         */
        this.uploadTips = '最佳尺寸 120 x 120 像素';
        /**
         * 上传指定文件后缀类型
         */
        this.uploadAcceptType = '.jpg,.png,.jpeg';
        /**
         * 设置裁剪形状
         */
        this.shape = 'rect';
        /**
         * 确定事件
         */
        this.thyConfirm = new EventEmitter();
        this.saving = false;
        this.notifyService = inject(ThyNotifyService);
        this.scale = 1;
        this.rotate = 0;
        this.scaleConfig = {
            maxScale: 3,
            minScale: 0.6,
            step: 0.1
        };
        this.sliderType = 'primary';
    }
    ngOnInit() { }
    selectImage(image) {
        if (image.files.length > 0) {
            this.image = image.files[0];
        }
        this.scale = 1;
        this.rotate = 0;
    }
    save() {
        const cropper = this.cropperRef.cropper;
        if (cropper) {
            this.saving = true;
            cropper.getCroppedCanvas().toBlob((blob) => {
                const file = new File([blob], 'avatar.png', { type: 'image/jpeg' });
                if (this.confirmAction) {
                    this.confirmAction(file)
                        .pipe(finalize(() => {
                        this.saving = false;
                    }))
                        .subscribe(() => {
                        this.close();
                    }, (error) => {
                        this.notifyService.error(error);
                    });
                }
                else {
                    this.thyConfirm.emit(file);
                    this.saving = false;
                }
            });
        }
        else {
            this.thyConfirm.emit();
        }
    }
    close() {
        if (this.dialogContainer) {
            this.ngZone.run(() => {
                this.dialog.close();
            });
        }
    }
    setRotate() {
        this.rotate = this.rotate + 90;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyImageCropperDialogComponent, deps: [{ token: i1$1.ThyDialog }, { token: i1$1.ThyDialogContainer, optional: true }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: ThyImageCropperDialogComponent, isStandalone: true, selector: "thy-image-cropper-dialog", inputs: { title: ["thyTitle", "title"], previewSizes: ["thyPreviewSizes", "previewSizes"], image: ["thyImage", "image"], uploadTips: ["thyUploadTips", "uploadTips"], uploadAcceptType: ["thyUploadAcceptType", "uploadAcceptType"], uploadSizeThreshold: ["thyUploadSizeThreshold", "uploadSizeThreshold"], viewMode: ["thyViewMode", "viewMode"], aspectRatio: ["thyAspectRatio", "aspectRatio"], shape: ["thyShape", "shape"], confirmAction: ["thyConfirmAction", "confirmAction"] }, outputs: { thyConfirm: "thyConfirm" }, host: { properties: { "class.thy-image-cropper-dialog-round": "shape === \"round\"" }, classAttribute: "thy-dialog-content thy-image-cropper-dialog" }, viewQueries: [{ propertyName: "cropperRef", first: true, predicate: ["cropper"], descendants: true, static: true }], ngImport: i0, template: "<thy-dialog-header [thyTitle]=\"'\u4E0A\u4F20' + title\"></thy-dialog-header>\n<thy-dialog-body class=\"cropper-dialog-body\">\n  <div class=\"cropper-content-container\">\n    <thy-image-cropper\n      #cropper\n      [thyImage]=\"image\"\n      [thyAspectRatio]=\"aspectRatio\"\n      [thyViewMode]=\"viewMode\"\n      [thyShape]=\"shape\"\n      [thyScale]=\"scale\"\n      [thyRotate]=\"rotate\"\n    ></thy-image-cropper>\n    <div class=\"zoom-container d-flex align-items-center mt-4 mb-4\">\n      <thy-slider\n        class=\"zoom-slider\"\n        [thyType]=\"sliderType\"\n        [thyMax]=\"scaleConfig.maxScale\"\n        [thyMin]=\"scaleConfig.minScale\"\n        [thyStep]=\"scaleConfig.step\"\n        [(ngModel)]=\"scale\"\n        thySize=\"sm\"\n      ></thy-slider>\n      <div><button thyButtonIcon=\"rotate-right\" class=\"pl-2\" (click)=\"setRotate()\"></button></div>\n    </div>\n    <div class=\"avatar-text-desc\">\n      <thy-file-select\n        thyStopPropagation\n        [thySizeThreshold]=\"uploadSizeThreshold\"\n        [thyAcceptType]=\"uploadAcceptType\"\n        (thyOnFileSelect)=\"selectImage($event)\"\n      >\n        <a href=\"javascript:;\" class=\"link-has-icon pl-0\"><thy-icon thyIconName=\"upload\" class=\"mr-1\"></thy-icon>\u91CD\u65B0\u4E0A\u4F20</a>\n      </thy-file-select>\n      <span class=\"text-desc\">{{ uploadTips }}</span>\n    </div>\n  </div>\n  <div class=\"preview-container\">\n    \u9884\u89C8\n    <div class=\"text-center\">\n      <ng-container *ngIf=\"previewSizes && previewSizes?.length\">\n        <ng-container *ngFor=\"let size of previewSizes\">\n          <div class=\"preview-image-warp\" [ngStyle]=\"size | thyCropperSizeStyle\"></div>\n          <div class=\"preview-image-size\">{{ size | thyCropperSizeText }}</div>\n        </ng-container>\n      </ng-container>\n    </div>\n  </div>\n</thy-dialog-body>\n\n<thy-dialog-footer thyShowBorderTop=\"true\" [thyAlign]=\"'right'\">\n  <button class=\"cancel\" thyButton=\"link-secondary\" (click)=\"close()\">\u53D6\u6D88</button>\n  <button thyButton=\"primary\" [thyLoading]=\"saving\" thyLoadingText=\"\u4E0A\u4F20\u4E2D\" (click)=\"save()\">\u786E\u5B9A</button>\n</thy-dialog-footer>\n", dependencies: [{ kind: "ngmodule", type: ThyDialogModule }, { kind: "component", type: i1$1.ThyDialogHeader, selector: "thy-dialog-header", inputs: ["thyTitle", "thySize", "thyDivided", "thyTitleTranslationKey", "thyIcon"], outputs: ["thyOnClose"], exportAs: ["thyDialogHeader"] }, { kind: "component", type: i1$1.ThyDialogBody, selector: "thy-dialog-body", inputs: ["thyClearPadding"], exportAs: ["thyDialogBody"] }, { kind: "component", type: i1$1.ThyDialogFooter, selector: "thy-dialog-footer", inputs: ["thyDivided", "thyAlign"], exportAs: ["thyDialogFooter"] }, { kind: "component", type: ThyImageCropperComponent, selector: "thy-image-cropper", inputs: ["thyImage", "thyImageErrorMessage", "thyViewMode", "thyAspectRatio", "thyShape", "thyScale", "thyRotate"], outputs: ["thyCropDataChanged", "thyImageReady"] }, { kind: "ngmodule", type: ThySliderModule }, { kind: "component", type: i2.ThySlider, selector: "thy-slider", inputs: ["thyVertical", "thyDisabled", "thyMax", "thyMin", "thyStep", "thyType", "thyColor", "thySize"], outputs: ["thyAfterChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "ngmodule", type: ThyButtonModule }, { kind: "component", type: i4.ThyButton, selector: "thy-button,[thy-button],[thyButton]", inputs: ["thyButton", "thyType", "thyLoading", "thyLoadingText", "thySize", "thyIcon", "thyBlock"] }, { kind: "component", type: i4.ThyButtonIcon, selector: "thy-button-icon,[thy-button-icon],[thyButtonIcon]", inputs: ["thySize", "thyIcon", "thyButtonIcon", "thyShape", "thyLight", "thyActive", "thyTheme", "thyColor"] }, { kind: "ngmodule", type: ThyUploadModule }, { kind: "component", type: i5.ThyFileSelect, selector: "[thyFileSelect],thy-file-select", inputs: ["thyMultiple", "thyAcceptFolder", "thyAcceptType", "thySizeThreshold"], outputs: ["thyOnFileSelect"] }, { kind: "component", type: ThyIcon, selector: "thy-icon, [thy-icon]", inputs: ["thyIconType", "thyTwotoneColor", "thyIconName", "thyIconRotate", "thyIconSet", "thyIconLegging", "thyIconLinearGradient"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "pipe", type: ThyCropperSizeTextPipe, name: "thyCropperSizeText" }, { kind: "pipe", type: ThyCropperSizeStylePipe, name: "thyCropperSizeStyle" }] }); }
}
__decorate([
    InputNumber()
], ThyImageCropperDialogComponent.prototype, "uploadSizeThreshold", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyImageCropperDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'thy-image-cropper-dialog', host: {
                        class: 'thy-dialog-content thy-image-cropper-dialog',
                        '[class.thy-image-cropper-dialog-round]': 'shape === "round"'
                    }, standalone: true, imports: [
                        ThyDialogModule,
                        ThyImageCropperComponent,
                        ThySliderModule,
                        FormsModule,
                        ThyButtonModule,
                        ThyUploadModule,
                        ThyIcon,
                        NgIf,
                        NgFor,
                        NgStyle,
                        ThyCropperSizeTextPipe,
                        ThyCropperSizeStylePipe
                    ], template: "<thy-dialog-header [thyTitle]=\"'\u4E0A\u4F20' + title\"></thy-dialog-header>\n<thy-dialog-body class=\"cropper-dialog-body\">\n  <div class=\"cropper-content-container\">\n    <thy-image-cropper\n      #cropper\n      [thyImage]=\"image\"\n      [thyAspectRatio]=\"aspectRatio\"\n      [thyViewMode]=\"viewMode\"\n      [thyShape]=\"shape\"\n      [thyScale]=\"scale\"\n      [thyRotate]=\"rotate\"\n    ></thy-image-cropper>\n    <div class=\"zoom-container d-flex align-items-center mt-4 mb-4\">\n      <thy-slider\n        class=\"zoom-slider\"\n        [thyType]=\"sliderType\"\n        [thyMax]=\"scaleConfig.maxScale\"\n        [thyMin]=\"scaleConfig.minScale\"\n        [thyStep]=\"scaleConfig.step\"\n        [(ngModel)]=\"scale\"\n        thySize=\"sm\"\n      ></thy-slider>\n      <div><button thyButtonIcon=\"rotate-right\" class=\"pl-2\" (click)=\"setRotate()\"></button></div>\n    </div>\n    <div class=\"avatar-text-desc\">\n      <thy-file-select\n        thyStopPropagation\n        [thySizeThreshold]=\"uploadSizeThreshold\"\n        [thyAcceptType]=\"uploadAcceptType\"\n        (thyOnFileSelect)=\"selectImage($event)\"\n      >\n        <a href=\"javascript:;\" class=\"link-has-icon pl-0\"><thy-icon thyIconName=\"upload\" class=\"mr-1\"></thy-icon>\u91CD\u65B0\u4E0A\u4F20</a>\n      </thy-file-select>\n      <span class=\"text-desc\">{{ uploadTips }}</span>\n    </div>\n  </div>\n  <div class=\"preview-container\">\n    \u9884\u89C8\n    <div class=\"text-center\">\n      <ng-container *ngIf=\"previewSizes && previewSizes?.length\">\n        <ng-container *ngFor=\"let size of previewSizes\">\n          <div class=\"preview-image-warp\" [ngStyle]=\"size | thyCropperSizeStyle\"></div>\n          <div class=\"preview-image-size\">{{ size | thyCropperSizeText }}</div>\n        </ng-container>\n      </ng-container>\n    </div>\n  </div>\n</thy-dialog-body>\n\n<thy-dialog-footer thyShowBorderTop=\"true\" [thyAlign]=\"'right'\">\n  <button class=\"cancel\" thyButton=\"link-secondary\" (click)=\"close()\">\u53D6\u6D88</button>\n  <button thyButton=\"primary\" [thyLoading]=\"saving\" thyLoadingText=\"\u4E0A\u4F20\u4E2D\" (click)=\"save()\">\u786E\u5B9A</button>\n</thy-dialog-footer>\n" }]
        }], ctorParameters: () => [{ type: i1$1.ThyDialog }, { type: i1$1.ThyDialogContainer, decorators: [{
                    type: Optional
                }] }, { type: i0.NgZone }], propDecorators: { title: [{
                type: Input,
                args: ['thyTitle']
            }], previewSizes: [{
                type: Input,
                args: ['thyPreviewSizes']
            }], image: [{
                type: Input,
                args: ['thyImage']
            }], uploadTips: [{
                type: Input,
                args: ['thyUploadTips']
            }], uploadAcceptType: [{
                type: Input,
                args: ['thyUploadAcceptType']
            }], uploadSizeThreshold: [{
                type: Input,
                args: ['thyUploadSizeThreshold']
            }], viewMode: [{
                type: Input,
                args: ['thyViewMode']
            }], aspectRatio: [{
                type: Input,
                args: ['thyAspectRatio']
            }], shape: [{
                type: Input,
                args: ['thyShape']
            }], confirmAction: [{
                type: Input,
                args: ['thyConfirmAction']
            }], thyConfirm: [{
                type: Output
            }], cropperRef: [{
                type: ViewChild,
                args: ['cropper', { static: true }]
            }] } });

class ThyImageCropperModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyImageCropperModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.3", ngImport: i0, type: ThyImageCropperModule, imports: [CommonModule,
            FormsModule,
            ThyLoadingModule,
            ThyUploadModule,
            ThyButtonModule,
            ThyDialogModule,
            ThyNotifyModule,
            ThySliderModule,
            ThyIconModule,
            ThyTooltipModule,
            ThyImageCropperComponent,
            ThyImageCropperDialogComponent,
            ThyCropperSizeTextPipe,
            ThyCropperSizeStylePipe], exports: [ThyImageCropperComponent, ThyImageCropperDialogComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyImageCropperModule, imports: [CommonModule,
            FormsModule,
            ThyLoadingModule,
            ThyUploadModule,
            ThyButtonModule,
            ThyDialogModule,
            ThyNotifyModule,
            ThySliderModule,
            ThyIconModule,
            ThyTooltipModule,
            ThyImageCropperComponent,
            ThyImageCropperDialogComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyImageCropperModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        ThyLoadingModule,
                        ThyUploadModule,
                        ThyButtonModule,
                        ThyDialogModule,
                        ThyNotifyModule,
                        ThySliderModule,
                        ThyIconModule,
                        ThyTooltipModule,
                        ThyImageCropperComponent,
                        ThyImageCropperDialogComponent,
                        ThyCropperSizeTextPipe,
                        ThyCropperSizeStylePipe
                    ],
                    exports: [ThyImageCropperComponent, ThyImageCropperDialogComponent],
                    providers: []
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ThyImageCropperComponent, ThyImageCropperDialogComponent, ThyImageCropperModule };
//# sourceMappingURL=tethys-pro-image-cropper.mjs.map
