import * as i0 from '@angular/core';
import { EventEmitter, Directive, Output, Component, HostBinding, ViewChild, Input, NgModule } from '@angular/core';
import { isString } from '@tethys/cdk';
import * as i1 from '@angular/platform-browser';
import { NgIf, CommonModule } from '@angular/common';

/**
 * @internal
 */
class ThyMediaPlayerBaseComponent {
    set fileSrc(value) {
        if (isString(value)) {
            this.internalFileSrc = this.sanitizer.bypassSecurityTrustResourceUrl(value);
        }
        else {
            this.internalFileSrc = value;
        }
    }
    get fileSrc() {
        return this.internalFileSrc;
    }
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.showErrorTip = false;
        this.showMedia = true;
        this.errorTipText = '';
        this.internalFileSrc = '';
        /**
         * 媒体元数据被加载完成后触发 能拿到媒体尺寸、时长等
         */
        this.thyLoadedMetadata = new EventEmitter();
    }
    ngOnInit() { }
    onLoadedmetadata(event) { }
    onCanPlay() {
        this.showErrorTip = false;
    }
    onError(event) {
        const errorCode = event.target.error?.code;
        if (errorCode === 3 || errorCode === 4) {
            this.errorTipText = this.errorTips['formatError'];
        }
        else {
            this.errorTipText = this.errorTips['networkError'];
        }
        setTimeout(() => {
            this.showErrorTip = true;
        }, 1000);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyMediaPlayerBaseComponent, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.2.3", type: ThyMediaPlayerBaseComponent, isStandalone: true, selector: "[thyMediaPlayerBase]", outputs: { thyLoadedMetadata: "thyLoadedMetadata" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyMediaPlayerBaseComponent, decorators: [{
            type: Directive,
            args: [{
                    selector: '[thyMediaPlayerBase]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }], propDecorators: { thyLoadedMetadata: [{
                type: Output
            }] } });

class ThyAudioPlayerComponent extends ThyMediaPlayerBaseComponent {
    /**
     * 媒体资源的url
     */
    set thySrc(src) {
        this.fileSrc = src;
    }
    constructor(sanitizer) {
        super(sanitizer);
        this.sanitizer = sanitizer;
        this.audioPlayerClass = true;
        /**
         * 当下载到足够播放的媒体文件，是否可以自动播放
         */
        this.thyAutoPlay = false;
        this.errorTips = {
            formatError: '该音频暂不支持预览，请升级浏览器版本或下载查看',
            networkError: '当前网络异常，请刷新后重试'
        };
    }
    onLoadedmetadata(event) {
        const duration = this.audio?.nativeElement?.duration;
        if (!(duration && duration > 0)) {
            this.showErrorTip = true;
        }
        this.thyLoadedMetadata.emit(this.audio?.nativeElement);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyAudioPlayerComponent, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: ThyAudioPlayerComponent, isStandalone: true, selector: "thy-audio-player", inputs: { thySrc: "thySrc", thyAutoPlay: "thyAutoPlay" }, host: { properties: { "class.thy-audio-player": "this.audioPlayerClass" } }, viewQueries: [{ propertyName: "audio", first: true, predicate: ["audio"], descendants: true }], usesInheritance: true, ngImport: i0, template: `
        <div class="audio-content">
            <audio
                #audio
                class="audio"
                [src]="fileSrc"
                [muted]="false"
                [autoplay]="thyAutoPlay"
                [controls]="true"
                (loadedmetadata)="onLoadedmetadata($event)"
                (error)="onError($event)"
                (canplay)="onCanPlay()"
                *ngIf="showMedia"
            ></audio>
            <div class="error-tip" *ngIf="showErrorTip">
                {{ errorTipText }}
            </div>
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyAudioPlayerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'thy-audio-player',
                    template: `
        <div class="audio-content">
            <audio
                #audio
                class="audio"
                [src]="fileSrc"
                [muted]="false"
                [autoplay]="thyAutoPlay"
                [controls]="true"
                (loadedmetadata)="onLoadedmetadata($event)"
                (error)="onError($event)"
                (canplay)="onCanPlay()"
                *ngIf="showMedia"
            ></audio>
            <div class="error-tip" *ngIf="showErrorTip">
                {{ errorTipText }}
            </div>
        </div>
    `,
                    standalone: true,
                    imports: [NgIf]
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }], propDecorators: { audioPlayerClass: [{
                type: HostBinding,
                args: ['class.thy-audio-player']
            }], audio: [{
                type: ViewChild,
                args: ['audio']
            }], thySrc: [{
                type: Input
            }], thyAutoPlay: [{
                type: Input
            }] } });

class ThyVideoPlayerComponent extends ThyMediaPlayerBaseComponent {
    /**
     * 媒体资源的url
     */
    set thySrc(src) {
        this.fileSrc = src;
    }
    constructor(sanitizer) {
        super(sanitizer);
        this.sanitizer = sanitizer;
        this.class = 'thy-video-player thy-media-player';
        /**
         * 当下载到足够播放的媒体文件，是否可以自动播放
         */
        this.thyAutoPlay = false;
        this.errorTips = {
            formatError: '该视频暂不支持预览，请升级浏览器版本或下载查看',
            networkError: '当前网络异常，请刷新后重试'
        };
    }
    ngOnInit() { }
    onLoadedmetadata(event) {
        this.thyLoadedMetadata.emit(this.video?.nativeElement);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyVideoPlayerComponent, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.2.3", type: ThyVideoPlayerComponent, isStandalone: true, selector: "thy-video-player", inputs: { thySrc: "thySrc", thyAutoPlay: "thyAutoPlay" }, host: { properties: { "class": "this.class" } }, viewQueries: [{ propertyName: "video", first: true, predicate: ["video"], descendants: true }], usesInheritance: true, ngImport: i0, template: `
        <video
            #video
            class="media-content"
            [src]="fileSrc"
            [muted]="false"
            [autoplay]="thyAutoPlay"
            [controls]="true"
            (loadedmetadata)="onLoadedmetadata($event)"
            (error)="onError($event)"
            (canplay)="onCanPlay()"
            *ngIf="showMedia"
        ></video>
        <div class="error-tip" *ngIf="showErrorTip">
            {{ errorTipText }}
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyVideoPlayerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'thy-video-player',
                    template: `
        <video
            #video
            class="media-content"
            [src]="fileSrc"
            [muted]="false"
            [autoplay]="thyAutoPlay"
            [controls]="true"
            (loadedmetadata)="onLoadedmetadata($event)"
            (error)="onError($event)"
            (canplay)="onCanPlay()"
            *ngIf="showMedia"
        ></video>
        <div class="error-tip" *ngIf="showErrorTip">
            {{ errorTipText }}
        </div>
    `,
                    standalone: true,
                    imports: [NgIf]
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }], propDecorators: { class: [{
                type: HostBinding,
                args: ['class']
            }], video: [{
                type: ViewChild,
                args: ['video']
            }], thySrc: [{
                type: Input
            }], thyAutoPlay: [{
                type: Input
            }] } });

class ThyProMediaModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyProMediaModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.2.3", ngImport: i0, type: ThyProMediaModule, imports: [CommonModule, ThyMediaPlayerBaseComponent, ThyVideoPlayerComponent, ThyAudioPlayerComponent], exports: [ThyVideoPlayerComponent, ThyAudioPlayerComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyProMediaModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.3", ngImport: i0, type: ThyProMediaModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, ThyMediaPlayerBaseComponent, ThyVideoPlayerComponent, ThyAudioPlayerComponent],
                    exports: [ThyVideoPlayerComponent, ThyAudioPlayerComponent],
                    providers: []
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ThyAudioPlayerComponent, ThyProMediaModule, ThyVideoPlayerComponent };
//# sourceMappingURL=tethys-pro-media.mjs.map
